Module commitment

Module commitment 

Implementation of Commitment API for ION DID method.

Structs

BlockHashCommitment
A Commitment whose hash is the PoW hash of a Bitcoin block.
BlockTimestampCommitment
A Commitment whose expected data is a Unix time and hasher and candidate data are obtained from a given DIDCommitment.
Complete
Unit struct for complete commitments.
IONCommitment
A commitment to ION DID Document data.
Incomplete
Unit struct for incomplete commitments.
IpfsChunkFileCommitment
A Commitment whose hash is an IPFS content identifier (CID) for an ION chunk file.
IpfsIndexFileCommitment
A Commitment whose hash is an IPFS content identifier (CID) for an ION Index file.
MerkleRootCommitment
A Commitment whose hash is the root of a Merkle tree of Bitcoin transaction IDs.
TxCommitment
A Commitment whose hash is a Bitcoin transaction ID.