pub struct IONController { /* private fields */ }Expand description
Struct for IONController.
Implementations
Sourceimpl IONController
impl IONController
Sourceimpl IONController
impl IONController
Sourcepub fn is_proof_in_doc_meta(&self, doc_meta: &DocumentMetadata) -> bool
pub fn is_proof_in_doc_meta(&self, doc_meta: &DocumentMetadata) -> bool
Checks whether there is a proof field in document metadata.
Sourcepub fn add_proof_service(&self, did: &str, proof: &str) -> DIDStatePatch
pub fn add_proof_service(&self, did: &str, proof: &str) -> DIDStatePatch
Returns a patch for adding a proof service.
Sourcepub fn is_commitment_key(
&self,
doc_meta: &DocumentMetadata,
key: &JWK,
key_type: KeyType,
) -> bool
pub fn is_commitment_key( &self, doc_meta: &DocumentMetadata, key: &JWK, key_type: KeyType, ) -> bool
Confirms whether a given key is the commitment in document metadata