Implementation of Commitment API for ION DID method.
Structs
- Block
Hash Commitment - A Commitment whose hash is the PoW hash of a Bitcoin block.
- Block
Timestamp Commitment - A Commitment whose expected data is a Unix time and hasher and candidate data are obtained from a given DIDCommitment.
- Complete
- Unit struct for complete commitments.
- IONCommitment
- A commitment to ION DID Document data.
- Incomplete
- Unit struct for incomplete commitments.
- Ipfs
Chunk File Commitment - A Commitment whose hash is an IPFS content identifier (CID) for an ION chunk file.
- Ipfs
Index File Commitment - A Commitment whose hash is an IPFS content identifier (CID) for an ION Index file.
- Merkle
Root Commitment - A Commitment whose hash is the root of a Merkle tree of Bitcoin transaction IDs.
- TxCommitment
- A Commitment whose hash is a Bitcoin transaction ID.